@@ -20,6 +20,7 @@ import ddt
 from keystonemiddleware import auth_token
 import mock
 
+from zaqar.common import consts
 from zaqar.common import urls
 from zaqar.tests.unit.transport.websocket import base
 from zaqar.tests.unit.transport.websocket import utils as test_utils
@@ -67,6 +68,18 @@ class AuthTest(base.V2Base):
         self.assertEqual(1, len(responses))
         self.assertEqual('200 OK', responses[0])
 
+        # Check that the env is available to future requests
+        req = json.dumps({'action': consts.MESSAGE_LIST,
+                          'body': {'queue_name': 'myqueue'},
+                          'headers': self.headers})
+        process_request = mock.patch.object(self.protocol._handler,
+                                            'process_request').start()
+        process_request.return_value = self.protocol._handler.create_response(
+            200, {})
+        self.protocol.onMessage(req, False)
+        self.assertEqual(1, process_request.call_count)
+        self.assertEqual(self.env, process_request.call_args[0][0]._env)
+
     def test_post_between_auth(self):
         headers = self.headers.copy()
         headers['X-Auth-Token'] = 'mytoken1'
@@ -77,7 +90,7 @@ class AuthTest(base.V2Base):
         msg_mock = msg_mock.start()
         self.protocol.onMessage(req, False)
 
-        req = test_utils.create_request("queue_list", {}, self.headers)
+        req = test_utils.create_request(consts.QUEUE_LIST, {}, self.headers)
         self.protocol.onMessage(req, False)
 
         self.assertEqual(1, msg_mock.call_count)
@@ -124,6 +137,34 @@ class AuthTest(base.V2Base):
         self.assertIn('cancelled', repr(handle))
         self.assertNotIn('cancelled', repr(self.protocol._deauth_handle))
 
+    def test_reauth_after_auth_failure(self):
+        headers = self.headers.copy()
+        headers['X-Auth-Token'] = 'wrong_token'
+        req = json.dumps({'action': 'authenticate', 'headers': headers})
+
+        msg_mock = mock.patch.object(self.protocol, 'sendMessage')
+        self.addCleanup(msg_mock.stop)
+        msg_mock = msg_mock.start()
+        # after authenticate failure, the _auth_app will be  None and the
+        # request will raise 401 error.
+        self.protocol.onMessage(req, False)
+        self.protocol._auth_response('401 error', 'Failed')
+        resp = json.loads(msg_mock.call_args[0][0])
+
+        self.assertEqual(401, resp['headers']['status'])
+        self.assertEqual('authenticate', resp['request']['action'])
+        self.assertIsNone(self.protocol._auth_app)
+
+        # try to authenticate again, "onMessage" should not return 403 because
+        # that the _auth_app was cleaned after auth failure.
+        headers['X-Auth-Token'] = 'mytoken'
+        req = json.dumps({'action': 'authenticate', 'headers': headers})
+        self.protocol.onMessage(req, False)
+
+        self.protocol._auth_response('200 OK', 'authenticate success')
+        resp = json.loads(msg_mock.call_args[0][0])
+        self.assertEqual(200, resp['headers']['status'])
+
     @ddt.data(True, False)
     def test_auth_response_serialization_format(self, in_binary):
         dumps, loads, create_req = test_utils.get_pack_tools(binary=in_binary)
@@ -158,7 +199,7 @@ class AuthTest(base.V2Base):
             'URL-Methods': ['GET'],
             'URL-Paths': ['/v2/queues/myqueue/messages']
         })
-        req = json.dumps({'action': 'message_list',
+        req = json.dumps({'action': consts.MESSAGE_LIST,
                           'body': {'queue_name': 'myqueue'},
                           'headers': headers})
         self.protocol.onMessage(req, False)
@@ -182,7 +223,7 @@ class AuthTest(base.V2Base):
             'URL-Methods': ['GET'],
             'URL-Paths': ['/v2/queues/otherqueue/messages']
         })
-        req = json.dumps({'action': 'message_list',
+        req = json.dumps({'action': consts.MESSAGE_LIST,
                           'body': {'queue_name': 'otherqueue'},
                           'headers': headers})
         self.protocol.onMessage(req, False)
@@ -206,7 +247,7 @@ class AuthTest(base.V2Base):
             'URL-Methods': ['GET'],
             'URL-Paths': ['/v2/queues/myqueue/messages']
         })
-        req = json.dumps({'action': 'message_delete',
+        req = json.dumps({'action': consts.MESSAGE_DELETE,
                           'body': {'queue_name': 'myqueue',
                                    'message_id': '123'},
                           'headers': headers})
