@@ -75,7 +75,8 @@ _TRANSPORT_LIMITS_OPTIONS = (
                deprecated_group='limits:transport',
                help='Defines the maximum message grace period in seconds.'),
 
-    cfg.ListOpt('subscriber_types', default=['http', 'https', 'mailto'],
+    cfg.ListOpt('subscriber_types', default=['http', 'https', 'mailto',
+                                             'trust+http', 'trust+https'],
                 help='Defines supported subscriber types.'),
 )
 
@@ -473,7 +474,7 @@ class Validator(object):
                     'must be at least {1} seconds long.')
 
             raise ValidationFailed(
-                msg, self._limits_conf.max_message_ttl, MIN_CLAIM_TTL)
+                msg, self._limits_conf.max_claim_ttl, MIN_CLAIM_TTL)
 
     def subscription_posting(self, subscription):
         """Restrictions on a creation of subscription.
@@ -539,6 +540,12 @@ class Validator(object):
             except OverflowError:
                 raise ValidationFailed(msg, datetime.datetime.max)
 
+    def subscription_confirming(self, confirm):
+        confirm = confirm.get('confirmed', None)
+        if not isinstance(confirm, bool):
+            msg = _(u"The 'confirmed' should be boolean.")
+            raise ValidationFailed(msg)
+
     def subscription_listing(self, limit=None, **kwargs):
         """Restrictions involving a list of subscriptions.
 
@@ -554,3 +561,10 @@ class Validator(object):
 
             raise ValidationFailed(
                 msg, self._limits_conf.max_subscriptions_per_page)
+
+    def get_limit_conf_value(self, limit_conf_name=None):
+        """Return the value of limit configuration.
+
+        :param limit_conf_name: configuration name
+        """
+        return self._limits_conf[limit_conf_name]
